==> openflowplugin-extension-nicira-0.7.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/ofpact/actions/ofpact/actions/nx/action/nat/_case/NxActionNat.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions.nx.action.nat._case;
import java.lang.Integer;
import javax.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpAddress;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.OfpactActions;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-action-nat {
 *   leaf flags {
 *     type uint16;
 *   }
 *   leaf range_present {
 *     type uint16;
 *   }
 *   leaf ip-address-min {
 *     type inet:ip-address;
 *   }
 *   leaf ip-address-max {
 *     type inet:ip-address;
 *   }
 *   leaf port-min {
 *     type uint16;
 *   }
 *   leaf port-max {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/ofpact-actions/ofpact-actions/nx-action-nat-case/nx-action-nat</i>
 *
 * <p>To create instances of this class use {@link NxActionNatBuilder}.
 * @see NxActionNatBuilder
 *
 */
public interface NxActionNat
    extends
    ChildOf<OfpactActions>,
    Augmentable<NxActionNat>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-nat");

    /**
     * @return <code>java.lang.Integer</code> <code>flags</code>, or <code>null</code> if not present
     */
    @Nullable
    Integer getFlags();
    
    /**
     * @return <code>java.lang.Integer</code> <code>rangePresent</code>, or <code>null</code> if not present
     */
    @Nullable
    Integer getRangePresent();
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpAddress</code> <code>ipAddressMin</code>, or <code>null</code> if not present
     */
    @Nullable
    IpAddress getIpAddressMin();
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpAddress</code> <code>ipAddressMax</code>, or <code>null</code> if not present
     */
    @Nullable
    IpAddress getIpAddressMax();
    
    /**
     * @return <code>java.lang.Integer</code> <code>portMin</code>, or <code>null</code> if not present
     */
    @Nullable
    Integer getPortMin();
    
    /**
     * @return <code>java.lang.Integer</code> <code>portMax</code>, or <code>null</code> if not present
     */
    @Nullable
    Integer getPortMax();

}

==> openflowplugin-extension-nicira-0.8.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/ofpact/actions/ofpact/actions/nx/action/nat/_case/NxActionNat.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions.nx.action.nat._case;
import java.lang.Integer;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpAddress;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.OfpactActions;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-action-nat {
 *   leaf flags {
 *     type uint16;
 *   }
 *   leaf range_present {
 *     type uint16;
 *   }
 *   leaf ip-address-min {
 *     type inet:ip-address;
 *   }
 *   leaf ip-address-max {
 *     type inet:ip-address;
 *   }
 *   leaf port-min {
 *     type uint16;
 *   }
 *   leaf port-max {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/ofpact-actions/ofpact-actions/nx-action-nat-case/nx-action-nat</i>
 *
 * <p>To create instances of this class use {@link NxActionNatBuilder}.
 * @see NxActionNatBuilder
 *
 */
public interface NxActionNat
    extends
    ChildOf<OfpactActions>,
    Augmentable<NxActionNat>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-nat");

    /**
     * @return <code>java.lang.Integer</code> <code>flags</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFlags();
    
    /**
     * @return <code>java.lang.Integer</code> <code>rangePresent</code>, or <code>null</code> if not present
     */
    @Nullable Integer getRangePresent();
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpAddress</code> <code>ipAddressMin</code>, or <code>null</code> if not present
     */
    @Nullable IpAddress getIpAddressMin();
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpAddress</code> <code>ipAddressMax</code>, or <code>null</code> if not present
     */
    @Nullable IpAddress getIpAddressMax();
    
    /**
     * @return <code>java.lang.Integer</code> <code>portMin</code>, or <code>null</code> if not present
     */
    @Nullable Integer getPortMin();
    
    /**
     * @return <code>java.lang.Integer</code> <code>portMax</code>, or <code>null</code> if not present
     */
    @Nullable Integer getPortMax();

}
